# coding: utf-8

"""
    Maestro API

    Maestro authors and executes experiences that allow non-coders the ability to define Simple Business Process without having to write code and to deploy them seamlessly without having to have development expertise  # noqa: E501

    OpenAPI spec version: 1.0.0
    Contact: devcenter@docusign.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from docusign_maestro.client.configuration import Configuration


class NewOrUpdatedWorkflowDefinitionResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'is_valid_workflow_definition': 'bool',
        'validation_errors': 'list[ValidationErrors]',
        'workflow_definition': 'WorkflowDefinition',
        'workflow_definition_id': 'str'
    }

    attribute_map = {
        'is_valid_workflow_definition': 'isValidWorkflowDefinition',
        'validation_errors': 'validationErrors',
        'workflow_definition': 'workflowDefinition',
        'workflow_definition_id': 'workflowDefinitionId'
    }

    def __init__(self, _configuration=None, **kwargs):  # noqa: E501
        """NewOrUpdatedWorkflowDefinitionResponse - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._is_valid_workflow_definition = None
        self._validation_errors = None
        self._workflow_definition = None
        self._workflow_definition_id = None
        self.discriminator = None

        setattr(self, "_{}".format('is_valid_workflow_definition'), kwargs.get('is_valid_workflow_definition', None))
        setattr(self, "_{}".format('validation_errors'), kwargs.get('validation_errors', None))
        setattr(self, "_{}".format('workflow_definition'), kwargs.get('workflow_definition', None))
        setattr(self, "_{}".format('workflow_definition_id'), kwargs.get('workflow_definition_id', None))

    @property
    def is_valid_workflow_definition(self):
        """Gets the is_valid_workflow_definition of this NewOrUpdatedWorkflowDefinitionResponse.  # noqa: E501


        :return: The is_valid_workflow_definition of this NewOrUpdatedWorkflowDefinitionResponse.  # noqa: E501
        :rtype: bool
        """
        return self._is_valid_workflow_definition

    @is_valid_workflow_definition.setter
    def is_valid_workflow_definition(self, is_valid_workflow_definition):
        """Sets the is_valid_workflow_definition of this NewOrUpdatedWorkflowDefinitionResponse.


        :param is_valid_workflow_definition: The is_valid_workflow_definition of this NewOrUpdatedWorkflowDefinitionResponse.  # noqa: E501
        :type: bool
        """
        if self._configuration.client_side_validation and is_valid_workflow_definition is None:
            raise ValueError("Invalid value for `is_valid_workflow_definition`, must not be `None`")  # noqa: E501

        self._is_valid_workflow_definition = is_valid_workflow_definition

    @property
    def validation_errors(self):
        """Gets the validation_errors of this NewOrUpdatedWorkflowDefinitionResponse.  # noqa: E501


        :return: The validation_errors of this NewOrUpdatedWorkflowDefinitionResponse.  # noqa: E501
        :rtype: list[ValidationErrors]
        """
        return self._validation_errors

    @validation_errors.setter
    def validation_errors(self, validation_errors):
        """Sets the validation_errors of this NewOrUpdatedWorkflowDefinitionResponse.


        :param validation_errors: The validation_errors of this NewOrUpdatedWorkflowDefinitionResponse.  # noqa: E501
        :type: list[ValidationErrors]
        """
        if self._configuration.client_side_validation and validation_errors is None:
            raise ValueError("Invalid value for `validation_errors`, must not be `None`")  # noqa: E501

        self._validation_errors = validation_errors

    @property
    def workflow_definition(self):
        """Gets the workflow_definition of this NewOrUpdatedWorkflowDefinitionResponse.  # noqa: E501


        :return: The workflow_definition of this NewOrUpdatedWorkflowDefinitionResponse.  # noqa: E501
        :rtype: WorkflowDefinition
        """
        return self._workflow_definition

    @workflow_definition.setter
    def workflow_definition(self, workflow_definition):
        """Sets the workflow_definition of this NewOrUpdatedWorkflowDefinitionResponse.


        :param workflow_definition: The workflow_definition of this NewOrUpdatedWorkflowDefinitionResponse.  # noqa: E501
        :type: WorkflowDefinition
        """
        if self._configuration.client_side_validation and workflow_definition is None:
            raise ValueError("Invalid value for `workflow_definition`, must not be `None`")  # noqa: E501

        self._workflow_definition = workflow_definition

    @property
    def workflow_definition_id(self):
        """Gets the workflow_definition_id of this NewOrUpdatedWorkflowDefinitionResponse.  # noqa: E501


        :return: The workflow_definition_id of this NewOrUpdatedWorkflowDefinitionResponse.  # noqa: E501
        :rtype: str
        """
        return self._workflow_definition_id

    @workflow_definition_id.setter
    def workflow_definition_id(self, workflow_definition_id):
        """Sets the workflow_definition_id of this NewOrUpdatedWorkflowDefinitionResponse.


        :param workflow_definition_id: The workflow_definition_id of this NewOrUpdatedWorkflowDefinitionResponse.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and workflow_definition_id is None:
            raise ValueError("Invalid value for `workflow_definition_id`, must not be `None`")  # noqa: E501

        self._workflow_definition_id = workflow_definition_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(NewOrUpdatedWorkflowDefinitionResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, NewOrUpdatedWorkflowDefinitionResponse):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, NewOrUpdatedWorkflowDefinitionResponse):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Maestro API

    Maestro authors and executes experiences that allow non-coders the ability to define Simple Business Process without having to write code and to deploy them seamlessly without having to have development expertise  # noqa: E501

    OpenAPI spec version: 1.0.0
    Contact: devcenter@docusign.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from setuptools import setup, find_packages, Command, os  # noqa: H301	

NAME = "docusign-maestro"
VERSION = "1.0.0"
# To install the library, run the following
#
# python setup.py install
#
# prerequisite: setuptools
# http://pypi.python.org/pypi/setuptools

REQUIRES = ["urllib3 >= 1.15", "six >= 1.8.0", "certifi >= 14.05.14", "python-dateutil >= 2.5.3", "setuptools >= 21.0.0", "PyJWT>=2.0.0", "cryptography>=2.5", "nose>=1.3.7"]

class CleanCommand(Command):
    """Custom clean command to tidy up the project root."""
    user_options = []
    def initialize_options(self):
        pass
    def finalize_options(self):
        pass
    def run(self):
        os.system('rm -vrf ./build ./dist ./*.pyc ./*.tgz ./*.egg-info')

this_directory = os.path.abspath(os.path.dirname(__file__))
with open(os.path.join(this_directory, 'README.md'), encoding='utf-8') as f:
    long_description = f.read()
    

setup(
    name=NAME,
    version=VERSION,
    description="Maestro API",
    author_email="devcenter@docusign.com",
    url="",
    keywords=["Swagger", "Maestro API"],
    install_requires=REQUIRES,
    packages=find_packages(),
    include_package_data=True,
    cmdclass={
        'clean': CleanCommand,
    },
    long_description=long_description,
    long_description_content_type='text/markdown'
)



# coding: utf-8

"""
    Maestro API

    Maestro authors and executes experiences that allow non-coders the ability to define Simple Business Process without having to write code and to deploy them seamlessly without having to have development expertise  # noqa: E501

    OpenAPI spec version: 1.0.0
    Contact: devcenter@docusign.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import sys
import os
import re

# python 2 and python 3 compatibility library
from six import iteritems

from ..client.configuration import Configuration
from ..client.api_client import ApiClient


class WorkflowManagementApi(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        config = Configuration()
        if api_client:
            self.api_client = api_client
        else:
            if not config.api_client:
                config.api_client = ApiClient()
            self.api_client = config.api_client

    def create_workflow_definition(self, account_id, body, **kwargs):
        """
        Creates a new workflow definition.
        Creates a new workflow definition.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.create_workflow_definition(account_id, body, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str account_id: Account ID (required)
        :param CreateOrUpdateWorkflowDefinitionRequestBody body: Request Body to create a new workflow definition. (required)
        :return: NewOrUpdatedWorkflowDefinitionResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.create_workflow_definition_with_http_info(account_id, body, **kwargs)
        else:
            (data) = self.create_workflow_definition_with_http_info(account_id, body, **kwargs)
            return data

    def create_workflow_definition_with_http_info(self, account_id, body, **kwargs):
        """
        Creates a new workflow definition.
        Creates a new workflow definition.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.create_workflow_definition_with_http_info(account_id, body, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str account_id: Account ID (required)
        :param CreateOrUpdateWorkflowDefinitionRequestBody body: Request Body to create a new workflow definition. (required)
        :return: NewOrUpdatedWorkflowDefinitionResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['account_id', 'body']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_workflow_definition" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'account_id' is set
        if ('account_id' not in params) or (params['account_id'] is None):
            raise ValueError("Missing the required parameter `account_id` when calling `create_workflow_definition`")
        # verify the required parameter 'body' is set
        if ('body' not in params) or (params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `create_workflow_definition`")


        collection_formats = {}

        resource_path = 'aow-manage/v1.0/management/accounts/{accountId}/workflowDefinitions'.replace('{format}', 'json')
        path_params = {}
        if 'account_id' in params:
            path_params['accountId'] = params['account_id']

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = []

        return self.api_client.call_api(resource_path, 'POST',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type='NewOrUpdatedWorkflowDefinitionResponse',
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def delete_workflow_definition(self, account_id, workflow_definition_id, **kwargs):
        """
        Deletes a workflow definition.
        Deletes a workflow definition.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.delete_workflow_definition(account_id, workflow_definition_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str account_id: Account ID (required)
        :param str workflow_definition_id: Workflow Definition ID (required)
        :return: WorkflowDeleteResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.delete_workflow_definition_with_http_info(account_id, workflow_definition_id, **kwargs)
        else:
            (data) = self.delete_workflow_definition_with_http_info(account_id, workflow_definition_id, **kwargs)
            return data

    def delete_workflow_definition_with_http_info(self, account_id, workflow_definition_id, **kwargs):
        """
        Deletes a workflow definition.
        Deletes a workflow definition.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.delete_workflow_definition_with_http_info(account_id, workflow_definition_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str account_id: Account ID (required)
        :param str workflow_definition_id: Workflow Definition ID (required)
        :return: WorkflowDeleteResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['account_id', 'workflow_definition_id']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_workflow_definition" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'account_id' is set
        if ('account_id' not in params) or (params['account_id'] is None):
            raise ValueError("Missing the required parameter `account_id` when calling `delete_workflow_definition`")
        # verify the required parameter 'workflow_definition_id' is set
        if ('workflow_definition_id' not in params) or (params['workflow_definition_id'] is None):
            raise ValueError("Missing the required parameter `workflow_definition_id` when calling `delete_workflow_definition`")


        collection_formats = {}

        resource_path = 'aow-manage/v1.0/management/accounts/{accountId}/workflowDefinitions/{workflowDefinitionId}'.replace('{format}', 'json')
        path_params = {}
        if 'account_id' in params:
            path_params['accountId'] = params['account_id']
        if 'workflow_definition_id' in params:
            path_params['workflowDefinitionId'] = params['workflow_definition_id']

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = []

        return self.api_client.call_api(resource_path, 'DELETE',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type='WorkflowDeleteResponse',
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def get_workflow_definition(self, account_id, workflow_definition_id, **kwargs):
        """
        Get Workflow Definition
        Returns a workflow definition.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_workflow_definition(account_id, workflow_definition_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str account_id: Account ID (required)
        :param str workflow_definition_id: Workflow Definition ID (required)
        :param str last_deployed_id: deployed workflow definition metadata object id
        :return: WorkflowDefinitionWithId
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.get_workflow_definition_with_http_info(account_id, workflow_definition_id, **kwargs)
        else:
            (data) = self.get_workflow_definition_with_http_info(account_id, workflow_definition_id, **kwargs)
            return data

    def get_workflow_definition_with_http_info(self, account_id, workflow_definition_id, **kwargs):
        """
        Get Workflow Definition
        Returns a workflow definition.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_workflow_definition_with_http_info(account_id, workflow_definition_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str account_id: Account ID (required)
        :param str workflow_definition_id: Workflow Definition ID (required)
        :param str last_deployed_id: deployed workflow definition metadata object id
        :return: WorkflowDefinitionWithId
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['account_id', 'workflow_definition_id', 'last_deployed_id']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_workflow_definition" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'account_id' is set
        if ('account_id' not in params) or (params['account_id'] is None):
            raise ValueError("Missing the required parameter `account_id` when calling `get_workflow_definition`")
        # verify the required parameter 'workflow_definition_id' is set
        if ('workflow_definition_id' not in params) or (params['workflow_definition_id'] is None):
            raise ValueError("Missing the required parameter `workflow_definition_id` when calling `get_workflow_definition`")


        collection_formats = {}

        resource_path = 'aow-manage/v1.0/management/accounts/{accountId}/workflowDefinitions/{workflowDefinitionId}'.replace('{format}', 'json')
        path_params = {}
        if 'account_id' in params:
            path_params['accountId'] = params['account_id']
        if 'workflow_definition_id' in params:
            path_params['workflowDefinitionId'] = params['workflow_definition_id']

        query_params = {}
        if 'last_deployed_id' in params:
            query_params['lastDeployedId'] = params['last_deployed_id']

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = []

        return self.api_client.call_api(resource_path, 'GET',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type='WorkflowDefinitionWithId',
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def get_workflow_definition_config_instances(self, account_id, workflow_definition_id, **kwargs):
        """
        Gets configuration instances
        Returns a list of configuration instances for a workflow definition
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_workflow_definition_config_instances(account_id, workflow_definition_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str account_id: Account ID (required)
        :param str workflow_definition_id: Workflow Definition ID (required)
        :return: GetConfigurationInstancesResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.get_workflow_definition_config_instances_with_http_info(account_id, workflow_definition_id, **kwargs)
        else:
            (data) = self.get_workflow_definition_config_instances_with_http_info(account_id, workflow_definition_id, **kwargs)
            return data

    def get_workflow_definition_config_instances_with_http_info(self, account_id, workflow_definition_id, **kwargs):
        """
        Gets configuration instances
        Returns a list of configuration instances for a workflow definition
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_workflow_definition_config_instances_with_http_info(account_id, workflow_definition_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str account_id: Account ID (required)
        :param str workflow_definition_id: Workflow Definition ID (required)
        :return: GetConfigurationInstancesResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['account_id', 'workflow_definition_id']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_workflow_definition_config_instances" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'account_id' is set
        if ('account_id' not in params) or (params['account_id'] is None):
            raise ValueError("Missing the required parameter `account_id` when calling `get_workflow_definition_config_instances`")
        # verify the required parameter 'workflow_definition_id' is set
        if ('workflow_definition_id' not in params) or (params['workflow_definition_id'] is None):
            raise ValueError("Missing the required parameter `workflow_definition_id` when calling `get_workflow_definition_config_instances`")


        collection_formats = {}

        resource_path = 'aow-manage/v1.0/management/accounts/{accountId}/workflowDefinitions/{workflowDefinitionId}/configInstances'.replace('{format}', 'json')
        path_params = {}
        if 'account_id' in params:
            path_params['accountId'] = params['account_id']
        if 'workflow_definition_id' in params:
            path_params['workflowDefinitionId'] = params['workflow_definition_id']

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = []

        return self.api_client.call_api(resource_path, 'GET',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type='GetConfigurationInstancesResponse',
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def get_workflow_definitions(self, account_id, **kwargs):
        """
        Get Workflow Definitions metadata
        Returns a list of workflow definitions' metadata.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_workflow_definitions(account_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str account_id: Account ID (required)
        :param str status: workflow definition metadata status
        :return: WorkflowDefinitionList
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.get_workflow_definitions_with_http_info(account_id, **kwargs)
        else:
            (data) = self.get_workflow_definitions_with_http_info(account_id, **kwargs)
            return data

    def get_workflow_definitions_with_http_info(self, account_id, **kwargs):
        """
        Get Workflow Definitions metadata
        Returns a list of workflow definitions' metadata.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_workflow_definitions_with_http_info(account_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str account_id: Account ID (required)
        :param str status: workflow definition metadata status
        :return: WorkflowDefinitionList
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['account_id', 'status']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_workflow_definitions" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'account_id' is set
        if ('account_id' not in params) or (params['account_id'] is None):
            raise ValueError("Missing the required parameter `account_id` when calling `get_workflow_definitions`")


        collection_formats = {}

        resource_path = 'aow-manage/v1.0/management/accounts/{accountId}/workflowDefinitions'.replace('{format}', 'json')
        path_params = {}
        if 'account_id' in params:
            path_params['accountId'] = params['account_id']

        query_params = {}
        if 'status' in params:
            query_params['status'] = params['status']

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = []

        return self.api_client.call_api(resource_path, 'GET',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type='WorkflowDefinitionList',
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def publish_or_un_publish_workflow_definition(self, account_id, workflow_definition_id, body, **kwargs):
        """
        Publishes or unpublishes a workflow definition.
        Publishes or unpublishes a workflow definition.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.publish_or_un_publish_workflow_definition(account_id, workflow_definition_id, body, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str account_id: Account ID (required)
        :param str workflow_definition_id: Workflow Definition ID (required)
        :param DeployRequest body: Request Body to publish or unpublish a workflow definition. (required)
        :return: DeployResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.publish_or_un_publish_workflow_definition_with_http_info(account_id, workflow_definition_id, body, **kwargs)
        else:
            (data) = self.publish_or_un_publish_workflow_definition_with_http_info(account_id, workflow_definition_id, body, **kwargs)
            return data

    def publish_or_un_publish_workflow_definition_with_http_info(self, account_id, workflow_definition_id, body, **kwargs):
        """
        Publishes or unpublishes a workflow definition.
        Publishes or unpublishes a workflow definition.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.publish_or_un_publish_workflow_definition_with_http_info(account_id, workflow_definition_id, body, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str account_id: Account ID (required)
        :param str workflow_definition_id: Workflow Definition ID (required)
        :param DeployRequest body: Request Body to publish or unpublish a workflow definition. (required)
        :return: DeployResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['account_id', 'workflow_definition_id', 'body']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method publish_or_un_publish_workflow_definition" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'account_id' is set
        if ('account_id' not in params) or (params['account_id'] is None):
            raise ValueError("Missing the required parameter `account_id` when calling `publish_or_un_publish_workflow_definition`")
        # verify the required parameter 'workflow_definition_id' is set
        if ('workflow_definition_id' not in params) or (params['workflow_definition_id'] is None):
            raise ValueError("Missing the required parameter `workflow_definition_id` when calling `publish_or_un_publish_workflow_definition`")
        # verify the required parameter 'body' is set
        if ('body' not in params) or (params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `publish_or_un_publish_workflow_definition`")


        collection_formats = {}

        resource_path = 'aow-manage/v1.0/management/accounts/{accountId}/workflowDefinitions/{workflowDefinitionId}/publish'.replace('{format}', 'json')
        path_params = {}
        if 'account_id' in params:
            path_params['accountId'] = params['account_id']
        if 'workflow_definition_id' in params:
            path_params['workflowDefinitionId'] = params['workflow_definition_id']

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = []

        return self.api_client.call_api(resource_path, 'POST',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type='DeployResponse',
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)

    def update_workflow_definition(self, account_id, workflow_definition_id, body, **kwargs):
        """
        Updates a workflow definition.
        Updates a workflow definition.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.update_workflow_definition(account_id, workflow_definition_id, body, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str account_id: Account ID (required)
        :param str workflow_definition_id: Workflow Definition ID (required)
        :param CreateOrUpdateWorkflowDefinitionRequestBody body: Request Body to update a workflow definition. (required)
        :return: NewOrUpdatedWorkflowDefinitionResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('callback'):
            return self.update_workflow_definition_with_http_info(account_id, workflow_definition_id, body, **kwargs)
        else:
            (data) = self.update_workflow_definition_with_http_info(account_id, workflow_definition_id, body, **kwargs)
            return data

    def update_workflow_definition_with_http_info(self, account_id, workflow_definition_id, body, **kwargs):
        """
        Updates a workflow definition.
        Updates a workflow definition.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.update_workflow_definition_with_http_info(account_id, workflow_definition_id, body, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str account_id: Account ID (required)
        :param str workflow_definition_id: Workflow Definition ID (required)
        :param CreateOrUpdateWorkflowDefinitionRequestBody body: Request Body to update a workflow definition. (required)
        :return: NewOrUpdatedWorkflowDefinitionResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['account_id', 'workflow_definition_id', 'body']
        all_params.append('callback')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_workflow_definition" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'account_id' is set
        if ('account_id' not in params) or (params['account_id'] is None):
            raise ValueError("Missing the required parameter `account_id` when calling `update_workflow_definition`")
        # verify the required parameter 'workflow_definition_id' is set
        if ('workflow_definition_id' not in params) or (params['workflow_definition_id'] is None):
            raise ValueError("Missing the required parameter `workflow_definition_id` when calling `update_workflow_definition`")
        # verify the required parameter 'body' is set
        if ('body' not in params) or (params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `update_workflow_definition`")


        collection_formats = {}

        resource_path = 'aow-manage/v1.0/management/accounts/{accountId}/workflowDefinitions/{workflowDefinitionId}'.replace('{format}', 'json')
        path_params = {}
        if 'account_id' in params:
            path_params['accountId'] = params['account_id']
        if 'workflow_definition_id' in params:
            path_params['workflowDefinitionId'] = params['workflow_definition_id']

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = []

        return self.api_client.call_api(resource_path, 'PUT',
                                        path_params,
                                        query_params,
                                        header_params,
                                        body=body_params,
                                        post_params=form_params,
                                        files=local_var_files,
                                        response_type='NewOrUpdatedWorkflowDefinitionResponse',
                                        auth_settings=auth_settings,
                                        callback=params.get('callback'),
                                        _return_http_data_only=params.get('_return_http_data_only'),
                                        _preload_content=params.get('_preload_content', True),
                                        _request_timeout=params.get('_request_timeout'),
                                        collection_formats=collection_formats)



# coding: utf-8

"""
    Maestro API

    Maestro authors and executes experiences that allow non-coders the ability to define Simple Business Process without having to write code and to deploy them seamlessly without having to have development expertise  # noqa: E501

    OpenAPI spec version: 1.0.0
    Contact: devcenter@docusign.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from docusign_maestro.client.configuration import Configuration


class DSWorkflowLane(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'lane_id': 'str',
        'lane_steps': 'list[object]'
    }

    attribute_map = {
        'lane_id': 'laneId',
        'lane_steps': 'laneSteps'
    }

    def __init__(self, _configuration=None, **kwargs):  # noqa: E501
        """DSWorkflowLane - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._lane_id = None
        self._lane_steps = None
        self.discriminator = None

        setattr(self, "_{}".format('lane_id'), kwargs.get('lane_id', None))
        setattr(self, "_{}".format('lane_steps'), kwargs.get('lane_steps', None))

    @property
    def lane_id(self):
        """Gets the lane_id of this DSWorkflowLane.  # noqa: E501


        :return: The lane_id of this DSWorkflowLane.  # noqa: E501
        :rtype: str
        """
        return self._lane_id

    @lane_id.setter
    def lane_id(self, lane_id):
        """Sets the lane_id of this DSWorkflowLane.


        :param lane_id: The lane_id of this DSWorkflowLane.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and lane_id is None:
            raise ValueError("Invalid value for `lane_id`, must not be `None`")  # noqa: E501

        self._lane_id = lane_id

    @property
    def lane_steps(self):
        """Gets the lane_steps of this DSWorkflowLane.  # noqa: E501

        A list of #/definitions/DSWorkflowStep. Each element is: A DS Workflow Step. This object should be any of the following object models: [#/definitions/DSServiceStep, #/definitions/DSTransformationStep, #/definitions/DSDocGenStep, #/definitions/DSSignStep]  # noqa: E501

        :return: The lane_steps of this DSWorkflowLane.  # noqa: E501
        :rtype: list[object]
        """
        return self._lane_steps

    @lane_steps.setter
    def lane_steps(self, lane_steps):
        """Sets the lane_steps of this DSWorkflowLane.

        A list of #/definitions/DSWorkflowStep. Each element is: A DS Workflow Step. This object should be any of the following object models: [#/definitions/DSServiceStep, #/definitions/DSTransformationStep, #/definitions/DSDocGenStep, #/definitions/DSSignStep]  # noqa: E501

        :param lane_steps: The lane_steps of this DSWorkflowLane.  # noqa: E501
        :type: list[object]
        """
        if self._configuration.client_side_validation and lane_steps is None:
            raise ValueError("Invalid value for `lane_steps`, must not be `None`")  # noqa: E501

        self._lane_steps = lane_steps

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(DSWorkflowLane, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DSWorkflowLane):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, DSWorkflowLane):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Maestro API

    Maestro authors and executes experiences that allow non-coders the ability to define Simple Business Process without having to write code and to deploy them seamlessly without having to have development expertise  # noqa: E501

    OpenAPI spec version: 1.0.0
    Contact: devcenter@docusign.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import json
from pprint import pformat
from six import iteritems


class OAuth(object):
    """
        NOTE: This class is auto generated by the swagger code generator program.
        Do not edit the class manually.
        """
    #  create and send envelopes, and obtain links for starting signing sessions.
    SCOPE_SIGNATURE = "signature"
    #  obtain a refresh token with an extended lifetime.
    SCOPE_EXTENDED = "extended"
    #  obtain access to the user’s account when the user is not present.
    SCOPE_IMPERSONATION = "impersonation"

    #  OAuth Base path constants
    #  Demo server base path
    DEMO_OAUTH_BASE_PATH = "account-d.docusign.com"
    #  Production server base path
    PRODUCTION_OAUTH_BASE_PATH = "account.docusign.com"
    #  Stage server base path
    STAGE_OAUTH_BASE_PATH = "account-s.docusign.com"
    #   JWT Grant Type
    GRANT_TYPE_JWT = "urn:ietf:params:oauth:grant-type:jwt-bearer"


class OAuthUserInfo(object):

    def __init__(self, sub=None, email=None, accounts=None, name=None, given_name=None, family_name=None,
                 created=None):

        self.swagger_types = {
            'sub': 'str',
            'email': 'str',
            'accounts': 'list[Account]',
            'name': 'str',
            'given_name': 'str',
            'family_name': 'str',
            'created': 'str'
        }

        self.attribute_map = {
            'sub': 'sub',
            'email': 'email',
            'accounts': 'accounts',
            'name': 'name',
            'given_name': 'given_name',
            'family_name': 'family_name',
            'created': 'created'
        }
        self._sub = sub
        self._email = email
        self._accounts = accounts
        self._name = name
        self._given_name = given_name
        self._family_name = family_name
        self._created = created

    @property
    def sub(self):
        return self._sub

    @sub.setter
    def sub(self, sub):
        self._sub = sub

    @property
    def created(self):
        return self._created

    @created.setter
    def created(self, created):
        self._created = created

    @property
    def email(self):
        return self._email

    @email.setter
    def email(self, email):
        self._email = email

    @property
    def name(self):
        return self._name

    @name.setter
    def name(self, name):
        self._name = name

    @property
    def given_name(self):
        return self._given_name

    @given_name.setter
    def given_name(self, given_name):
        self._given_name = given_name

    @property
    def family_name(self):
        return self._family_name

    @family_name.setter
    def family_name(self, family_name):
        self._family_name = family_name

    def list(self):
        return self._accounts

    @property
    def accounts(self):
        return self._accounts

    @accounts.setter
    def accounts(self, accounts):
        self._accounts = accounts

    def add_account(self, account):
        if not self.accounts:
            self._accounts = list()
        self._accounts.append(account)

    def get_accounts(self):
        if not self.accounts:
            self._accounts = list()
        return self._accounts

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def __str__(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def to_indented_string(self, obj):
        """
         Convert the given object to string with each line indented by 4
         spaces (except the first line).
        :param obj:
        :return:
        """
        if obj:
            return str(obj).replace("\n", "\n    ")
        return ""


class Account(object):
    def __init__(self, account_id=None, is_default=None, account_name=None, base_uri=None, organization=None):
        self.swagger_types = {
            'account_id': 'str',
            'is_default': 'str',
            'account_name': 'str',
            'base_uri': 'str',
            'organization': 'str',
        }

        self.attribute_map =  {
            'account_id': 'account_id',
            'is_default': 'is_default',
            'account_name': 'account_name',
            'base_uri': 'base_uri',
            'organization': 'organization',
        }
        self._account_id = account_id
        self.is_default = is_default
        self._account_name = account_name
        self._base_uri = base_uri
        self._organization = organization

    def get_is_default(self):
        return self.get_is_default

    @property
    def account_id(self):
        return self._account_id

    @account_id.setter
    def account_id(self, account_id):
        self._account_id = account_id

    @property
    def is_default(self):
        return self._is_default

    @is_default.setter
    def is_default(self, is_default):
        self._is_default = is_default

    @property
    def account_name(self):
        return self._account_name

    @account_name.setter
    def account_name(self, account_name):
        self._account_name = account_name

    @property
    def base_uri(self):
        return self._base_uri

    @base_uri.setter
    def base_uri(self, base_uri):
        self._base_uri = base_uri

    @property
    def organization(self):
        return self._organization

    @organization.setter
    def organization(self, organization):
        self._organization = organization


class Link(object):
    def __init__(self, rel=None, href=None):
        self._rel = rel
        self._href = href

    @property
    def rel(self):
        return self._rel

    @rel.setter
    def rel(self, rel):
        self._rel = rel

    @property
    def href(self):
        return self._href

    @href.setter
    def organization(self, href):
        self._href = href

    def __str__(self):
        return "class Link {\n    rel: {}\n    href: {}".format(self.to_indented_string(self.rel),
                                                                self.to_indented_string(self.href))

    def to_indented_string(self, obj):
        """
         Convert the given object to string with each line indented by 4
         spaces (except the first line).
        :param obj: 
        :return: 
        """
        if obj:
            return str(obj).replace("\n", "\n    ")
        return None

    def __eq__(self, other):
        if not other:
            return False
        return (self.rel == other.rel or self.rel and self.rel == other.rel) and \
                (self.href == other.href or self.href and self.href == other.href)

    def to_json(self):
        pass


class Organization(object):
    def __init__(self, organization_id=None, links=None):
        self._organization_id = organization_id
        self._links = links

    @property
    def organization_id(self):
        return self._organization_id

    @organization_id.setter
    def organization_id(self, organization_id):
        self._organization_id = organization_id

    @property
    def links(self):
        return self._links

    @links.setter
    def links(self, links):
        self._links = links

    def list(self):
        if not self._links:
            self._links = list()
        return self._links

    def add_links(self, link):
        if not self.links:
            self.links = list()
        self._links.append(link)

    def __str__(self):
        return "class Organization {\n    organization_id: {}\n    links: {}".format(
            self.to_indented_string(self._organization_id),
            self.to_indented_string(self._links)
        )

    def to_indented_string(self, obj):

        if obj:
            return str(obj).replace("\n", "\n    ")
        return None

    def __eq__(self, other):
        if not other:
            return False
        return (self.organization_id == other.organization_id or self.organization_id
                and self.organization_id == other.organization_id) and\
               (self.links == other.links or self.links and self.links == other.links)


class OAuthToken(object):

    def __init__(self, access_token=None, data=None, expires_in=None, refresh_token=None, scope=None, token_type=None):
        """
        OAuthToken - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'access_token': 'str',
            'data': 'list[NameValue]',
            'expires_in': 'str',
            'refresh_token': 'str',
            'scope': 'str',
            'token_type': 'str'
        }

        self.attribute_map = {
            'access_token': 'access_token',
            'data': 'data',
            'expires_in': 'expires_in',
            'refresh_token': 'refresh_token',
            'scope': 'scope',
            'token_type': 'token_type'
        }

        self._access_token = access_token
        self._data = data
        self._expires_in = expires_in
        self._refresh_token = refresh_token
        self._scope = scope
        self._token_type = token_type

    @property
    def access_token(self):
        """
        Gets the access_token of this OAuthToken.
        Access token information.

        :return: The access_token of this OAuthToken.
        :rtype: str
        """
        return self._access_token

    @access_token.setter
    def access_token(self, access_token):
        """
        Sets the access_token of this OAuthToken.
        Access token information.

        :param access_token: The access_token of this OAuthToken.
        :type: str
        """

        self._access_token = access_token

    @property
    def data(self):
        """
        Gets the data of this OAuthToken.
        

        :return: The data of this OAuthToken.
        :rtype: list[NameValue]
        """
        return self._data

    @data.setter
    def data(self, data):
        """
        Sets the data of this OAuthToken.
        

        :param data: The data of this OAuthToken.
        :type: list[NameValue]
        """

        self._data = data

    @property
    def expires_in(self):
        """
        Gets the expires_in of this OAuthToken.
        

        :return: The expires_in of this OAuthToken.
        :rtype: str
        """
        return self._expires_in

    @expires_in.setter
    def expires_in(self, expires_in):
        """
        Sets the expires_in of this OAuthToken.
        

        :param expires_in: The expires_in of this OAuthToken.
        :type: str
        """

        self._expires_in = expires_in

    @property
    def refresh_token(self):
        """
        Gets the refresh_token of this OAuthToken.
        

        :return: The refresh_token of this OAuthToken.
        :rtype: str
        """
        return self._refresh_token

    @refresh_token.setter
    def refresh_token(self, refresh_token):
        """
        Sets the refresh_token of this OAuthToken.
        

        :param refresh_token: The refresh_token of this OAuthToken.
        :type: str
        """

        self._refresh_token = refresh_token

    @property
    def scope(self):
        """
        Gets the scope of this OAuthToken.
        Must be set to \"api\".

        :return: The scope of this OAuthToken.
        :rtype: str
        """
        return self._scope

    @scope.setter
    def scope(self, scope):
        """
        Sets the scope of this OAuthToken.
        Must be set to \"api\".

        :param scope: The scope of this OAuthToken.
        :type: str
        """

        self._scope = scope

    @property
    def token_type(self):
        """
        Gets the token_type of this OAuthToken.
        

        :return: The token_type of this OAuthToken.
        :rtype: str
        """
        return self._token_type

    @token_type.setter
    def token_type(self, token_type):
        """
        Sets the token_type of this OAuthToken.
        

        :param token_type: The token_type of this OAuthToken.
        :type: str
        """

        self._token_type = token_type

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other


# coding: utf-8

"""
    Maestro API

    Maestro authors and executes experiences that allow non-coders the ability to define Simple Business Process without having to write code and to deploy them seamlessly without having to have development expertise  # noqa: E501

    OpenAPI spec version: 1.0.0
    Contact: devcenter@docusign.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from docusign_maestro.client.configuration import Configuration


class WorkflowDefinition(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'account_id': 'str',
        'created_by_name': 'str',
        'document_version': 'str',
        'participants': 'dict(str, Participant)',
        'schema_version': 'str',
        'steps': 'list[object]',
        'trigger': 'DSWorkflowTrigger',
        'variables': 'dict(str, object)',
        'workflow_description': 'str',
        'workflow_name': 'str'
    }

    attribute_map = {
        'account_id': 'accountId',
        'created_by_name': 'createdByName',
        'document_version': 'documentVersion',
        'participants': 'participants',
        'schema_version': 'schemaVersion',
        'steps': 'steps',
        'trigger': 'trigger',
        'variables': 'variables',
        'workflow_description': 'workflowDescription',
        'workflow_name': 'workflowName'
    }

    def __init__(self, _configuration=None, **kwargs):  # noqa: E501
        """WorkflowDefinition - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._account_id = None
        self._created_by_name = None
        self._document_version = None
        self._participants = None
        self._schema_version = None
        self._steps = None
        self._trigger = None
        self._variables = None
        self._workflow_description = None
        self._workflow_name = None
        self.discriminator = None

        setattr(self, "_{}".format('account_id'), kwargs.get('account_id', None))
        setattr(self, "_{}".format('created_by_name'), kwargs.get('created_by_name', None))
        setattr(self, "_{}".format('document_version'), kwargs.get('document_version', None))
        setattr(self, "_{}".format('participants'), kwargs.get('participants', None))
        setattr(self, "_{}".format('schema_version'), kwargs.get('schema_version', None))
        setattr(self, "_{}".format('steps'), kwargs.get('steps', None))
        setattr(self, "_{}".format('trigger'), kwargs.get('trigger', None))
        setattr(self, "_{}".format('variables'), kwargs.get('variables', None))
        setattr(self, "_{}".format('workflow_description'), kwargs.get('workflow_description', None))
        setattr(self, "_{}".format('workflow_name'), kwargs.get('workflow_name', None))

    @property
    def account_id(self):
        """Gets the account_id of this WorkflowDefinition.  # noqa: E501


        :return: The account_id of this WorkflowDefinition.  # noqa: E501
        :rtype: str
        """
        return self._account_id

    @account_id.setter
    def account_id(self, account_id):
        """Sets the account_id of this WorkflowDefinition.


        :param account_id: The account_id of this WorkflowDefinition.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and account_id is None:
            raise ValueError("Invalid value for `account_id`, must not be `None`")  # noqa: E501

        self._account_id = account_id

    @property
    def created_by_name(self):
        """Gets the created_by_name of this WorkflowDefinition.  # noqa: E501

        The name of the user who created this workflow definition  # noqa: E501

        :return: The created_by_name of this WorkflowDefinition.  # noqa: E501
        :rtype: str
        """
        return self._created_by_name

    @created_by_name.setter
    def created_by_name(self, created_by_name):
        """Sets the created_by_name of this WorkflowDefinition.

        The name of the user who created this workflow definition  # noqa: E501

        :param created_by_name: The created_by_name of this WorkflowDefinition.  # noqa: E501
        :type: str
        """

        self._created_by_name = created_by_name

    @property
    def document_version(self):
        """Gets the document_version of this WorkflowDefinition.  # noqa: E501


        :return: The document_version of this WorkflowDefinition.  # noqa: E501
        :rtype: str
        """
        return self._document_version

    @document_version.setter
    def document_version(self, document_version):
        """Sets the document_version of this WorkflowDefinition.


        :param document_version: The document_version of this WorkflowDefinition.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and document_version is None:
            raise ValueError("Invalid value for `document_version`, must not be `None`")  # noqa: E501

        self._document_version = document_version

    @property
    def participants(self):
        """Gets the participants of this WorkflowDefinition.  # noqa: E501

        A DS Workflow participant record  # noqa: E501

        :return: The participants of this WorkflowDefinition.  # noqa: E501
        :rtype: dict(str, Participant)
        """
        return self._participants

    @participants.setter
    def participants(self, participants):
        """Sets the participants of this WorkflowDefinition.

        A DS Workflow participant record  # noqa: E501

        :param participants: The participants of this WorkflowDefinition.  # noqa: E501
        :type: dict(str, Participant)
        """

        self._participants = participants

    @property
    def schema_version(self):
        """Gets the schema_version of this WorkflowDefinition.  # noqa: E501


        :return: The schema_version of this WorkflowDefinition.  # noqa: E501
        :rtype: str
        """
        return self._schema_version

    @schema_version.setter
    def schema_version(self, schema_version):
        """Sets the schema_version of this WorkflowDefinition.


        :param schema_version: The schema_version of this WorkflowDefinition.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and schema_version is None:
            raise ValueError("Invalid value for `schema_version`, must not be `None`")  # noqa: E501

        self._schema_version = schema_version

    @property
    def steps(self):
        """Gets the steps of this WorkflowDefinition.  # noqa: E501

        A list of #/definitions/DSWorkflowStep. Each element is: A DS Workflow Step. This object should be any of the following object models: [#/definitions/DSServiceStep, #/definitions/DSTransformationStep, #/definitions/DSDocGenStep, #/definitions/DSSignStep]  # noqa: E501

        :return: The steps of this WorkflowDefinition.  # noqa: E501
        :rtype: list[object]
        """
        return self._steps

    @steps.setter
    def steps(self, steps):
        """Sets the steps of this WorkflowDefinition.

        A list of #/definitions/DSWorkflowStep. Each element is: A DS Workflow Step. This object should be any of the following object models: [#/definitions/DSServiceStep, #/definitions/DSTransformationStep, #/definitions/DSDocGenStep, #/definitions/DSSignStep]  # noqa: E501

        :param steps: The steps of this WorkflowDefinition.  # noqa: E501
        :type: list[object]
        """
        if self._configuration.client_side_validation and steps is None:
            raise ValueError("Invalid value for `steps`, must not be `None`")  # noqa: E501

        self._steps = steps

    @property
    def trigger(self):
        """Gets the trigger of this WorkflowDefinition.  # noqa: E501


        :return: The trigger of this WorkflowDefinition.  # noqa: E501
        :rtype: DSWorkflowTrigger
        """
        return self._trigger

    @trigger.setter
    def trigger(self, trigger):
        """Sets the trigger of this WorkflowDefinition.


        :param trigger: The trigger of this WorkflowDefinition.  # noqa: E501
        :type: DSWorkflowTrigger
        """
        if self._configuration.client_side_validation and trigger is None:
            raise ValueError("Invalid value for `trigger`, must not be `None`")  # noqa: E501

        self._trigger = trigger

    @property
    def variables(self):
        """Gets the variables of this WorkflowDefinition.  # noqa: E501

        A DS Workflow variable record  # noqa: E501

        :return: The variables of this WorkflowDefinition.  # noqa: E501
        :rtype: dict(str, object)
        """
        return self._variables

    @variables.setter
    def variables(self, variables):
        """Sets the variables of this WorkflowDefinition.

        A DS Workflow variable record  # noqa: E501

        :param variables: The variables of this WorkflowDefinition.  # noqa: E501
        :type: dict(str, object)
        """
        if self._configuration.client_side_validation and variables is None:
            raise ValueError("Invalid value for `variables`, must not be `None`")  # noqa: E501

        self._variables = variables

    @property
    def workflow_description(self):
        """Gets the workflow_description of this WorkflowDefinition.  # noqa: E501


        :return: The workflow_description of this WorkflowDefinition.  # noqa: E501
        :rtype: str
        """
        return self._workflow_description

    @workflow_description.setter
    def workflow_description(self, workflow_description):
        """Sets the workflow_description of this WorkflowDefinition.


        :param workflow_description: The workflow_description of this WorkflowDefinition.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and workflow_description is None:
            raise ValueError("Invalid value for `workflow_description`, must not be `None`")  # noqa: E501

        self._workflow_description = workflow_description

    @property
    def workflow_name(self):
        """Gets the workflow_name of this WorkflowDefinition.  # noqa: E501


        :return: The workflow_name of this WorkflowDefinition.  # noqa: E501
        :rtype: str
        """
        return self._workflow_name

    @workflow_name.setter
    def workflow_name(self, workflow_name):
        """Sets the workflow_name of this WorkflowDefinition.


        :param workflow_name: The workflow_name of this WorkflowDefinition.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and workflow_name is None:
            raise ValueError("Invalid value for `workflow_name`, must not be `None`")  # noqa: E501

        self._workflow_name = workflow_name

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(WorkflowDefinition, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, WorkflowDefinition):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, WorkflowDefinition):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Maestro API

    Maestro authors and executes experiences that allow non-coders the ability to define Simple Business Process without having to write code and to deploy them seamlessly without having to have development expertise  # noqa: E501

    OpenAPI spec version: 1.0.0
    Contact: devcenter@docusign.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from docusign_maestro.client.configuration import Configuration


class DSIdvStepInput(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'background_color_branding': 'object',
        'expected_full_name': 'object',
        'retry_limit': 'object',
        'text_color_branding': 'object'
    }

    attribute_map = {
        'background_color_branding': 'backgroundColorBranding',
        'expected_full_name': 'expectedFullName',
        'retry_limit': 'retryLimit',
        'text_color_branding': 'textColorBranding'
    }

    def __init__(self, _configuration=None, **kwargs):  # noqa: E501
        """DSIdvStepInput - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._background_color_branding = None
        self._expected_full_name = None
        self._retry_limit = None
        self._text_color_branding = None
        self.discriminator = None

        setattr(self, "_{}".format('background_color_branding'), kwargs.get('background_color_branding', None))
        setattr(self, "_{}".format('expected_full_name'), kwargs.get('expected_full_name', None))
        setattr(self, "_{}".format('retry_limit'), kwargs.get('retry_limit', None))
        setattr(self, "_{}".format('text_color_branding'), kwargs.get('text_color_branding', None))

    @property
    def background_color_branding(self):
        """Gets the background_color_branding of this DSIdvStepInput.  # noqa: E501

        Reference of #/definitions/StringOrVariableOrTransformation. Object stands for a String or a Variable or a Transformation. This object should be any of the following object models or types: [string, #/definitions/DSWorkflowVariable, #/definitions/DSWorkflowTransformationExpression]  # noqa: E501

        :return: The background_color_branding of this DSIdvStepInput.  # noqa: E501
        :rtype: object
        """
        return self._background_color_branding

    @background_color_branding.setter
    def background_color_branding(self, background_color_branding):
        """Sets the background_color_branding of this DSIdvStepInput.

        Reference of #/definitions/StringOrVariableOrTransformation. Object stands for a String or a Variable or a Transformation. This object should be any of the following object models or types: [string, #/definitions/DSWorkflowVariable, #/definitions/DSWorkflowTransformationExpression]  # noqa: E501

        :param background_color_branding: The background_color_branding of this DSIdvStepInput.  # noqa: E501
        :type: object
        """
        if self._configuration.client_side_validation and background_color_branding is None:
            raise ValueError("Invalid value for `background_color_branding`, must not be `None`")  # noqa: E501

        self._background_color_branding = background_color_branding

    @property
    def expected_full_name(self):
        """Gets the expected_full_name of this DSIdvStepInput.  # noqa: E501

        Reference of #/definitions/StringOrVariableOrTransformation. Object stands for a String or a Variable or a Transformation. This object should be any of the following object models or types: [string, #/definitions/DSWorkflowVariable, #/definitions/DSWorkflowTransformationExpression]  # noqa: E501

        :return: The expected_full_name of this DSIdvStepInput.  # noqa: E501
        :rtype: object
        """
        return self._expected_full_name

    @expected_full_name.setter
    def expected_full_name(self, expected_full_name):
        """Sets the expected_full_name of this DSIdvStepInput.

        Reference of #/definitions/StringOrVariableOrTransformation. Object stands for a String or a Variable or a Transformation. This object should be any of the following object models or types: [string, #/definitions/DSWorkflowVariable, #/definitions/DSWorkflowTransformationExpression]  # noqa: E501

        :param expected_full_name: The expected_full_name of this DSIdvStepInput.  # noqa: E501
        :type: object
        """
        if self._configuration.client_side_validation and expected_full_name is None:
            raise ValueError("Invalid value for `expected_full_name`, must not be `None`")  # noqa: E501

        self._expected_full_name = expected_full_name

    @property
    def retry_limit(self):
        """Gets the retry_limit of this DSIdvStepInput.  # noqa: E501

        This object should be any of the following object models or types: [number, #/definitions/DSWorkflowVariable, #/definitions/DSWorkflowTransformationExpression]  # noqa: E501

        :return: The retry_limit of this DSIdvStepInput.  # noqa: E501
        :rtype: object
        """
        return self._retry_limit

    @retry_limit.setter
    def retry_limit(self, retry_limit):
        """Sets the retry_limit of this DSIdvStepInput.

        This object should be any of the following object models or types: [number, #/definitions/DSWorkflowVariable, #/definitions/DSWorkflowTransformationExpression]  # noqa: E501

        :param retry_limit: The retry_limit of this DSIdvStepInput.  # noqa: E501
        :type: object
        """
        if self._configuration.client_side_validation and retry_limit is None:
            raise ValueError("Invalid value for `retry_limit`, must not be `None`")  # noqa: E501

        self._retry_limit = retry_limit

    @property
    def text_color_branding(self):
        """Gets the text_color_branding of this DSIdvStepInput.  # noqa: E501

        Reference of #/definitions/StringOrVariableOrTransformation. Object stands for a String or a Variable or a Transformation. This object should be any of the following object models or types: [string, #/definitions/DSWorkflowVariable, #/definitions/DSWorkflowTransformationExpression]  # noqa: E501

        :return: The text_color_branding of this DSIdvStepInput.  # noqa: E501
        :rtype: object
        """
        return self._text_color_branding

    @text_color_branding.setter
    def text_color_branding(self, text_color_branding):
        """Sets the text_color_branding of this DSIdvStepInput.

        Reference of #/definitions/StringOrVariableOrTransformation. Object stands for a String or a Variable or a Transformation. This object should be any of the following object models or types: [string, #/definitions/DSWorkflowVariable, #/definitions/DSWorkflowTransformationExpression]  # noqa: E501

        :param text_color_branding: The text_color_branding of this DSIdvStepInput.  # noqa: E501
        :type: object
        """
        if self._configuration.client_side_validation and text_color_branding is None:
            raise ValueError("Invalid value for `text_color_branding`, must not be `None`")  # noqa: E501

        self._text_color_branding = text_color_branding

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(DSIdvStepInput, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DSIdvStepInput):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, DSIdvStepInput):
            return True

        return self.to_dict() != other.to_dict()
